@@ -898,7 +898,7 @@ module Sass
             (?!
               url\(
             )
-            [^()\[\]{}"'#/ \t\r\n\f#{top_level ? ";!" : ""}]
+            [^()\[\]{}"'#/ \t\r\n\f#{top_level ? ";" : ""}]
           |
             \#(?!\{)
           |
